@@ -21,6 +21,10 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <hildon/hildon.h>
 #include <hildon/hildon-file-chooser-dialog.h>
 #include <glib.h>
@@ -33,6 +37,9 @@
 #include "queen-beecon-advanced-tools-dialog.h"
 #include "queen-beecon-exec-async.h"
 
+#include "he-helper.h"
+#include "he-about-dialog.h"
+
 extern gchar *qbwExecReason[];
 
 guint checksum(gchar *buffer)
@@ -68,6 +75,19 @@ void on_logger_picker_value_changed(HildonPickerButton * button, QueenBeecon *se
 	}
 }
 
+void aboutWBt_clicked_cb(HildonButton *button, gpointer data)
+{
+	he_about_dialog_present(NULL,
+                        "Queen Beecon Widget" /* auto-detect app name */,
+                        "queen-beecon",
+                        VERSION,
+                        "Super powerful and customizable\nWidget generation engine",
+                        "(c) 2010 Alessandro Peralma (... Hic Sunt Leones!)",
+                        "http://wiki.maemo.org/Queen_BeeCon_Widget",
+                        "https://garage.maemo.org/tracker/?group_id=1295",
+                        "https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=QTSK26NUKNXFC");
+}
+
 void testDriveBt_clicked_cb(HildonButton * button, QueenBeecon *self)
 {
 #define LINE_BUFFER_LENGTH 32768
@@ -178,13 +198,16 @@ void updateCommandBt_clicked_cb ( HildonButton * button, QueenBeecon *self )
 
 	if (cmdSel>=0) { //Update command in list
 		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) Current Title Command to update [%s]", self, self->priv->c_titles[cmdSel]);
-		EditCommand(self, g_strdup(self->priv->c_titles[cmdSel]), g_strdup(c), FALSE, cmdSel);
+		EditCommand(self, g_strdup(self->priv->c_titles[cmdSel]), g_strdup(c), TRUE, cmdSel);
 	} else { //Update command in instance
 		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) Current Title Instance Command to update [%s]", self, self->priv->instanceTitle);
 		EditCommand(self, g_strdup(self->priv->instanceTitle), g_strdup(c), TRUE, cmdSel);
 	}
-	hildon_banner_show_informationf (NULL, NULL, "Command successfully updated.");
+	queen_beecon_write_settings (self, TRUE); // We write commands to config file
+	hildon_banner_show_informationf (NULL, NULL, "Command/Instance successfully updated.");
 	g_free(c);
+	self->priv->instanceUpdateOK=TRUE;
+	gtk_dialog_response(GTK_DIALOG (self->priv->advancedDialog), GTK_RESPONSE_NONE);
 }
 
 void importCommandBt_clicked_cb ( HildonButton * button, QueenBeecon *self )
@@ -328,7 +351,11 @@ void exportCommandBt_clicked_cb ( HildonButton * button, QueenBeecon *self )
 	}
 	cmdSel = hildon_picker_button_get_active (HILDON_PICKER_BUTTON (self->priv->commandPicker));
 	qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) cmdSel %d", self, cmdSel);
-	gchar *exportData = g_strdup_printf("title=%s\ncommand=%s", self->priv->c_titles[cmdSel], c);
+	gchar *exportData;
+	if (cmdSel>=0)
+		exportData = g_strdup_printf("title=%s\ncommand=%s", self->priv->c_titles[cmdSel], c);
+	else
+		exportData = g_strdup_printf("title=%s\ncommand=%s", self->priv->instanceTitle, c);
 	qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) exportData (checksum here applies = %d", self, checksum(exportData));
 	gchar* headerVersion = g_strdup_printf("[queen-beecon-header]\nversion=%f\nchecksum=%d\n[queen-beecon-exported-command]\n%s", QUEEN_BEECON_SETTINGS_VERSION, checksum(exportData),exportData);//very trivial :)
 	qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) headerVersion %s", self, headerVersion);
@@ -630,7 +657,7 @@ void exportFileBufferBt_clicked_cb ( HildonButton * button, QueenBeecon *self )
 	gtk_widget_destroy (file_chooser);
 }
 
-gboolean queen_beecon_advanced_dialog ( QueenBeecon *self, gint cmdSel )
+gboolean queen_beecon_advanced_dialog ( QueenBeecon *self, gint *cmdSel )
 {
 	qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V1, "(%p) %s", self, G_STRFUNC);
 	HildonGtkInputMode input_mode;
@@ -658,14 +685,23 @@ gboolean queen_beecon_advanced_dialog ( QueenBeecon *self, gint cmdSel )
 	gtk_box_pack_start (GTK_BOX (content_area), cmdSelectionLabel, FALSE, FALSE, 0);
 
     GtkWidget *cmdTestDriveLabelHelp = gtk_label_new ("");
-	gtk_label_set_markup (GTK_LABEL (cmdTestDriveLabelHelp), "<span font_desc=\"Nokia Sans 13\">Type command you would like to execute and press <u>TestDrive</u> to see RAW Output in box below.</span>");//AP1
+	gtk_label_set_markup (GTK_LABEL (cmdTestDriveLabelHelp), "<span font_desc=\"Nokia Sans 13\">Type command you would like to execute and press <u>Run</u> to see RAW Output in box below.</span>");//AP1
 	gtk_box_pack_start (GTK_BOX (content_area), cmdTestDriveLabelHelp, TRUE, TRUE, 0);
 
 	//BEGIN Command Selector
 
 	GtkWidget *testDriveBox = gtk_hbox_new (FALSE, 0);
 
-	GtkWidget *loggerSelector = hildon_touch_selector_new_text ();
+	GtkWidget *aboutW = hildon_button_new_with_text (HILDON_SIZE_AUTO_HEIGHT |
+                                          HILDON_SIZE_AUTO_WIDTH, HILDON_BUTTON_ARRANGEMENT_VERTICAL,
+										  NULL,
+                                          NULL);
+	hildon_button_set_image (HILDON_BUTTON (aboutW), gtk_image_new_from_stock (GTK_STOCK_INFO, GTK_ICON_SIZE_MENU));
+	hildon_button_set_alignment (HILDON_BUTTON (aboutW), 0.5, 0.5, 0, 0);//AP1
+	g_signal_connect (aboutW, "clicked", G_CALLBACK (aboutWBt_clicked_cb), self);
+    gtk_box_pack_start (GTK_BOX (testDriveBox), aboutW, FALSE, FALSE, 0);
+
+    GtkWidget *loggerSelector = hildon_touch_selector_new_text ();
 	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (loggerSelector), "Disable");
 	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (loggerSelector), "v0");
 	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (loggerSelector), "v1");
@@ -674,8 +710,9 @@ gboolean queen_beecon_advanced_dialog ( QueenBeecon *self, gint cmdSel )
 	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (loggerSelector), "v4");
 	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (loggerSelector), "Reset");
 
-	GtkWidget *loggerPicker = hildon_picker_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
-	hildon_button_set_title (HILDON_BUTTON (loggerPicker), "Log:");
+    GtkWidget *loggerPicker = hildon_picker_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
+	hildon_button_set_image (HILDON_BUTTON (loggerPicker), gtk_image_new_from_stock (GTK_STOCK_SELECT_ALL, GTK_ICON_SIZE_MENU));
+    hildon_button_set_title (HILDON_BUTTON (loggerPicker), "Log:");
 	hildon_button_set_alignment (HILDON_BUTTON (loggerPicker), 0, 0.5, 0, 0);
 	hildon_picker_button_set_selector (HILDON_PICKER_BUTTON (loggerPicker), HILDON_TOUCH_SELECTOR (loggerSelector));
 	hildon_picker_button_set_active (HILDON_PICKER_BUTTON (loggerPicker), qbw_logger(QBW_LOGGER_GET_VERBOSITY, QBW_LOGGER_VNULL, NULL));
@@ -687,17 +724,18 @@ gboolean queen_beecon_advanced_dialog ( QueenBeecon *self, gint cmdSel )
 		hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (commandPickerSelector), self->priv->c_titles[i]);
 	}
 	self->priv->commandPicker = hildon_picker_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
-	hildon_button_set_title (HILDON_BUTTON (self->priv->commandPicker), "Commands: ");
+	hildon_button_set_image (HILDON_BUTTON (self->priv->commandPicker), gtk_image_new_from_stock (GTK_STOCK_INDEX, GTK_ICON_SIZE_MENU));
+	hildon_button_set_title (HILDON_BUTTON (self->priv->commandPicker), "Command:");
 	hildon_button_set_alignment (HILDON_BUTTON (self->priv->commandPicker), 0, 0.5, 0, 0);
 	hildon_picker_button_set_selector (HILDON_PICKER_BUTTON (self->priv->commandPicker), HILDON_TOUCH_SELECTOR (commandPickerSelector));
-	hildon_picker_button_set_active (HILDON_PICKER_BUTTON (self->priv->commandPicker), cmdSel);
+	hildon_picker_button_set_active (HILDON_PICKER_BUTTON (self->priv->commandPicker), *cmdSel);
 	gtk_box_pack_start (GTK_BOX (testDriveBox), self->priv->commandPicker, TRUE, TRUE, 0);
 
 	GtkWidget *testDriveBt = hildon_button_new_with_text (HILDON_SIZE_FINGER_HEIGHT |
                                           HILDON_SIZE_AUTO_WIDTH, HILDON_BUTTON_ARRANGEMENT_VERTICAL,
-										  "TestDrive",
-                                          NULL);
-	hildon_button_set_value (HILDON_BUTTON (testDriveBt), "Command");
+										  NULL,
+                                          "Run");
+	hildon_button_set_image (HILDON_BUTTON (testDriveBt), gtk_image_new_from_stock (GTK_STOCK_EXECUTE, GTK_ICON_SIZE_MENU));
 	hildon_button_set_alignment (HILDON_BUTTON (testDriveBt), 0, 0.5, 0, 0);//AP1
 	g_signal_connect (testDriveBt, "clicked", G_CALLBACK (testDriveBt_clicked_cb), self);
     gtk_box_pack_start (GTK_BOX (testDriveBox), testDriveBt, FALSE, FALSE, 0);
@@ -705,28 +743,30 @@ gboolean queen_beecon_advanced_dialog ( QueenBeecon *self, gint cmdSel )
 
 	GtkWidget *updateCmdBt = hildon_button_new_with_text (HILDON_SIZE_FINGER_HEIGHT |
                                           HILDON_SIZE_AUTO_WIDTH, HILDON_BUTTON_ARRANGEMENT_VERTICAL,
-										  "Update",
-                                          NULL);
+										  NULL,
+                                          "Save");
+	hildon_button_set_image (HILDON_BUTTON (updateCmdBt), gtk_image_new_from_stock (GTK_STOCK_OK, GTK_ICON_SIZE_MENU));
 	hildon_button_set_alignment (HILDON_BUTTON (updateCmdBt), 0, 0.5, 0, 0);//AP1
-	hildon_button_set_value (HILDON_BUTTON (updateCmdBt), "Command");
 	g_signal_connect (updateCmdBt, "clicked", G_CALLBACK (updateCommandBt_clicked_cb), self);
     gtk_box_pack_start (GTK_BOX (testDriveBox), updateCmdBt, FALSE, FALSE, 0);
 
 	GtkWidget *copyCmdBt = hildon_button_new_with_text (HILDON_SIZE_FINGER_HEIGHT |
                                           HILDON_SIZE_AUTO_WIDTH, HILDON_BUTTON_ARRANGEMENT_VERTICAL,
-										  "Copy",
+										  NULL,
                                           NULL);
+	hildon_button_set_image (HILDON_BUTTON (copyCmdBt), gtk_image_new_from_stock (GTK_STOCK_COPY, GTK_ICON_SIZE_MENU));
 	hildon_button_set_alignment (HILDON_BUTTON (copyCmdBt), 0, 0.5, 0, 0);//AP1
-	hildon_button_set_value (HILDON_BUTTON (copyCmdBt), "Command");
+	//hildon_button_set_value (HILDON_BUTTON (copyCmdBt), "Command");
 	g_signal_connect (copyCmdBt, "clicked", G_CALLBACK (copyCommandBt_clicked_cb), self);
     gtk_box_pack_start (GTK_BOX (testDriveBox), copyCmdBt, FALSE, FALSE, 0);
 
     GtkWidget *pasteCmdBt = hildon_button_new_with_text (HILDON_SIZE_FINGER_HEIGHT |
                                           HILDON_SIZE_AUTO_WIDTH, HILDON_BUTTON_ARRANGEMENT_VERTICAL,
-										  "Paste",
+										  NULL,
                                           NULL);
+	hildon_button_set_image (HILDON_BUTTON (pasteCmdBt), gtk_image_new_from_stock (GTK_STOCK_PASTE, GTK_ICON_SIZE_MENU));
 	hildon_button_set_alignment (HILDON_BUTTON (pasteCmdBt), 0, 0.5, 0, 0);//AP1
-	hildon_button_set_value (HILDON_BUTTON (pasteCmdBt), "Command");
+	//hildon_button_set_value (HILDON_BUTTON (pasteCmdBt), "Command");
 	g_signal_connect (pasteCmdBt, "clicked", G_CALLBACK (pasteCommandBt_clicked_cb), self);
     gtk_box_pack_start (GTK_BOX (testDriveBox), pasteCmdBt, FALSE, FALSE, 0);
 
@@ -734,7 +774,7 @@ gboolean queen_beecon_advanced_dialog ( QueenBeecon *self, gint cmdSel )
 
 	GtkWidget *cmdTestDrive = hildon_text_view_new ();
 	input_mode = hildon_gtk_text_view_get_input_mode(GTK_TEXT_VIEW (cmdTestDrive));
-	input_mode &= ~HILDON_GTK_INPUT_MODE_AUTOCAP; hildon_gtk_text_view_set_input_mode(GTK_TEXT_VIEW (cmdTestDrive), input_mode);
+	input_mode &= ~HILDON_GTK_INPUT_MODE_AUTOCAP; input_mode |= HILDON_GTK_INPUT_MODE_MULTILINE | HILDON_GTK_INPUT_MODE_FULL; hildon_gtk_text_view_set_input_mode(GTK_TEXT_VIEW (cmdTestDrive), input_mode);
 	gtk_widget_set_size_request (GTK_WIDGET (cmdTestDrive), -1, 150);//AP
 	gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (cmdTestDrive), GTK_WRAP_WORD_CHAR);
 	gtk_box_pack_start (GTK_BOX (content_area), cmdTestDrive, TRUE, TRUE, 0);
@@ -755,37 +795,41 @@ gboolean queen_beecon_advanced_dialog ( QueenBeecon *self, gint cmdSel )
 
 	GtkWidget *importCommandBt = hildon_button_new_with_text (HILDON_SIZE_FINGER_HEIGHT |
                                           HILDON_SIZE_AUTO_WIDTH, HILDON_BUTTON_ARRANGEMENT_VERTICAL,
-										  "Import",
-                                          NULL);
+										  NULL,
+                                          "Import Buffer\nto Command");
+	hildon_button_set_image (HILDON_BUTTON (importCommandBt), gtk_image_new_from_stock (GTK_STOCK_LEAVE_FULLSCREEN, GTK_ICON_SIZE_MENU));
 	hildon_button_set_alignment (HILDON_BUTTON (importCommandBt), 0, 0.5, 0, 0);//AP1
-	hildon_button_set_value (HILDON_BUTTON (importCommandBt), "Buffer to Command");
+	//hildon_button_set_value (HILDON_BUTTON (importCommandBt), "Buffer to Command");
 	g_signal_connect (importCommandBt, "clicked", G_CALLBACK (importCommandBt_clicked_cb), self);
     gtk_box_pack_start (GTK_BOX (cmdImportBox), importCommandBt, TRUE, TRUE, 0);
 
 	GtkWidget *pasteFromClipboardBt = hildon_button_new_with_text (HILDON_SIZE_FINGER_HEIGHT |
                                           HILDON_SIZE_AUTO_WIDTH, HILDON_BUTTON_ARRANGEMENT_VERTICAL,
-										  "Paste",
-                                          NULL);
+										  NULL,
+										  "Paste Clipboard\nto Buffer");
+	hildon_button_set_image (HILDON_BUTTON (pasteFromClipboardBt), gtk_image_new_from_stock (GTK_STOCK_PASTE, GTK_ICON_SIZE_MENU));
 	hildon_button_set_alignment (HILDON_BUTTON (pasteFromClipboardBt), 0, 0.5, 0, 0);//AP1
-	hildon_button_set_value (HILDON_BUTTON (pasteFromClipboardBt), "Clipboard to Buffer");
+	//hildon_button_set_value (HILDON_BUTTON (pasteFromClipboardBt), "Clipboard to Buffer");
 	g_signal_connect (pasteFromClipboardBt, "clicked", G_CALLBACK (pasteFromClipboardADBExportImportBt_clicked_cb), self);
     gtk_box_pack_start (GTK_BOX (cmdImportBox), pasteFromClipboardBt, TRUE, TRUE, 0);
 
     GtkWidget *importFileBufferBt = hildon_button_new_with_text (HILDON_SIZE_FINGER_HEIGHT |
-                                              HILDON_SIZE_AUTO_WIDTH, HILDON_BUTTON_ARRANGEMENT_VERTICAL,
-    										  "Import",
-                                              NULL);
+                                          HILDON_SIZE_AUTO_WIDTH, HILDON_BUTTON_ARRANGEMENT_VERTICAL,
+                                          NULL,
+    									  "Import File\nto Buffer");
+	hildon_button_set_image (HILDON_BUTTON (importFileBufferBt), gtk_image_new_from_stock (GTK_STOCK_OPEN, GTK_ICON_SIZE_MENU));
     hildon_button_set_alignment (HILDON_BUTTON (importFileBufferBt), 0, 0.5, 0, 0);//AP1
-    hildon_button_set_value (HILDON_BUTTON (importFileBufferBt), "File to Buffer");
+    //hildon_button_set_value (HILDON_BUTTON (importFileBufferBt), "File to\nBuffer");
     g_signal_connect (importFileBufferBt, "clicked", G_CALLBACK (importFileBufferBt_clicked_cb), self);
     gtk_box_pack_start (GTK_BOX (cmdImportBox), importFileBufferBt, TRUE, TRUE, 0);
 
 	GtkWidget *importInstanceBt = hildon_button_new_with_text (HILDON_SIZE_FINGER_HEIGHT |
                                           HILDON_SIZE_AUTO_WIDTH, HILDON_BUTTON_ARRANGEMENT_VERTICAL,
-										  "Import",
-                                          NULL);
+										  NULL,
+                                          "Import Buffer\nto Beecon");
+	hildon_button_set_image (HILDON_BUTTON (importInstanceBt), gtk_image_new_from_stock (GTK_STOCK_LEAVE_FULLSCREEN, GTK_ICON_SIZE_MENU));
 	hildon_button_set_alignment (HILDON_BUTTON (importInstanceBt), 0, 0.5, 0, 0);//AP1
-	hildon_button_set_value (HILDON_BUTTON (importInstanceBt), "Buffer to Beecon");
+	//hildon_button_set_value (HILDON_BUTTON (importInstanceBt), "Buffer to Beecon");
 	g_signal_connect (importInstanceBt, "clicked", G_CALLBACK (importInstanceBt_clicked_cb), self);
     gtk_box_pack_start (GTK_BOX (cmdImportBox), importInstanceBt, TRUE, TRUE, 0);
 
@@ -795,37 +839,41 @@ gboolean queen_beecon_advanced_dialog ( QueenBeecon *self, gint cmdSel )
 
 	GtkWidget *exportCommandBt = hildon_button_new_with_text (HILDON_SIZE_FINGER_HEIGHT |
                                           HILDON_SIZE_AUTO_WIDTH, HILDON_BUTTON_ARRANGEMENT_VERTICAL,
-										  "Export",
-                                          NULL);
+										  NULL,
+										  "Export Command\nto Buffer");
+	hildon_button_set_image (HILDON_BUTTON (exportCommandBt), gtk_image_new_from_stock (GTK_STOCK_FULLSCREEN, GTK_ICON_SIZE_MENU));
 	hildon_button_set_alignment (HILDON_BUTTON (exportCommandBt), 0, 0.5, 0, 0);//AP1
-	hildon_button_set_value (HILDON_BUTTON (exportCommandBt), "Command to Buffer");
+	//hildon_button_set_value (HILDON_BUTTON (exportCommandBt), "Command to Buffer");
 	g_signal_connect (exportCommandBt, "clicked", G_CALLBACK (exportCommandBt_clicked_cb), self);
     gtk_box_pack_start (GTK_BOX (cmdExportBox), exportCommandBt, TRUE, TRUE, 0);
 
 	GtkWidget *copyToClipboardBt = hildon_button_new_with_text (HILDON_SIZE_FINGER_HEIGHT |
                                           HILDON_SIZE_AUTO_WIDTH, HILDON_BUTTON_ARRANGEMENT_VERTICAL,
-										  "Copy",
-                                          NULL);
+										  NULL,
+										  "Copy Buffer\nto Clipboard");
+	hildon_button_set_image (HILDON_BUTTON (copyToClipboardBt), gtk_image_new_from_stock (GTK_STOCK_COPY, GTK_ICON_SIZE_MENU));
 	hildon_button_set_alignment (HILDON_BUTTON (copyToClipboardBt), 0, 0.5, 0, 0);//AP1
-	hildon_button_set_value (HILDON_BUTTON (copyToClipboardBt), "Buffer to Clipboard");
+	//hildon_button_set_value (HILDON_BUTTON (copyToClipboardBt), "Buffer to Clipboard");
 	g_signal_connect (copyToClipboardBt, "clicked", G_CALLBACK (copyToClipboardADBExportImportBt_clicked_cb), self);
     gtk_box_pack_start (GTK_BOX (cmdExportBox), copyToClipboardBt, TRUE, TRUE, 0);
 
     GtkWidget *exportFileBufferBt = hildon_button_new_with_text (HILDON_SIZE_FINGER_HEIGHT |
-                                              HILDON_SIZE_AUTO_WIDTH, HILDON_BUTTON_ARRANGEMENT_VERTICAL,
-    										  "Export",
-                                              NULL);
+                                          HILDON_SIZE_AUTO_WIDTH, HILDON_BUTTON_ARRANGEMENT_VERTICAL,
+   										  NULL,
+   										  "Export Buffer\nto File");
+	hildon_button_set_image (HILDON_BUTTON (exportFileBufferBt), gtk_image_new_from_stock (GTK_STOCK_SAVE, GTK_ICON_SIZE_MENU));
     hildon_button_set_alignment (HILDON_BUTTON (exportFileBufferBt), 0, 0.5, 0, 0);//AP1
-    hildon_button_set_value (HILDON_BUTTON (exportFileBufferBt), "Buffer to File");
+    //hildon_button_set_value (HILDON_BUTTON (exportFileBufferBt), "Buffer to File");
     g_signal_connect (exportFileBufferBt, "clicked", G_CALLBACK (exportFileBufferBt_clicked_cb), self);
     gtk_box_pack_start (GTK_BOX (cmdExportBox), exportFileBufferBt, TRUE, TRUE, 0);
 
     GtkWidget *exportInstanceBt = hildon_button_new_with_text (HILDON_SIZE_FINGER_HEIGHT |
                                           HILDON_SIZE_AUTO_WIDTH, HILDON_BUTTON_ARRANGEMENT_VERTICAL,
-										  "Export",
-                                          NULL);
+										  NULL,
+										  "Export Beecon\nto Buffer");
+	hildon_button_set_image (HILDON_BUTTON (exportInstanceBt), gtk_image_new_from_stock (GTK_STOCK_FULLSCREEN, GTK_ICON_SIZE_MENU));
 	hildon_button_set_alignment (HILDON_BUTTON (exportInstanceBt), 0, 0.5, 0, 0);//AP1
-	hildon_button_set_value (HILDON_BUTTON (exportInstanceBt), "Beecon to Buffer");
+	//hildon_button_set_value (HILDON_BUTTON (exportInstanceBt), "Beecon to Buffer");
 	g_signal_connect (exportInstanceBt, "clicked", G_CALLBACK (exportInstanceBt_clicked_cb), self);
     gtk_box_pack_start (GTK_BOX (cmdExportBox), exportInstanceBt, TRUE, TRUE, 0);
 
@@ -860,10 +908,10 @@ gboolean queen_beecon_advanced_dialog ( QueenBeecon *self, gint cmdSel )
 	g_signal_connect (G_OBJECT (loggerPicker), "value-changed",G_CALLBACK (on_logger_picker_value_changed), self);
 	g_signal_connect (G_OBJECT (self->priv->commandPicker), "value-changed",G_CALLBACK (on_command_picker_value_changed), self);
 
-	cmdSel = hildon_touch_selector_get_active (HILDON_TOUCH_SELECTOR (commandPickerSelector), 0);
-	if (cmdSel>=0) {
-		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) Working on global selector title=[%s] command=[%s]", self, self->priv->c_titles[cmdSel], self->priv->c_commands[cmdSel]);
-		gchar *c = g_strdup(self->priv->c_commands[cmdSel]);
+	*cmdSel = hildon_touch_selector_get_active (HILDON_TOUCH_SELECTOR (commandPickerSelector), 0);
+	if (*cmdSel>=0) {
+		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) Working on global selector title=[%s] command=[%s]", self, self->priv->c_titles[*cmdSel], self->priv->c_commands[*cmdSel]);
+		gchar *c = g_strdup(self->priv->c_commands[*cmdSel]);
 		gtk_text_buffer_set_text(self->priv->cmdTestDriveBuffer,c,-1);
 		g_free(c);
 	} else {
@@ -872,6 +920,7 @@ gboolean queen_beecon_advanced_dialog ( QueenBeecon *self, gint cmdSel )
 		gtk_text_buffer_set_text(self->priv->cmdTestDriveBuffer,c,-1);
 		g_free(c);
 	}
+	self->priv->instanceUpdateOK=FALSE;
 	self->priv->instanceImportOK=FALSE;
 
 	queen_beecon_config_file_housekeeping(self); // Housekeeping!!! How HARD!!!! :)
@@ -887,6 +936,8 @@ gboolean queen_beecon_advanced_dialog ( QueenBeecon *self, gint cmdSel )
 				break;
 			default:
 				qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) Time to go back... response %d", self, dialogRunResponse);
+				if (self->priv->instanceUpdateOK)
+					*cmdSel = hildon_touch_selector_get_active (HILDON_TOUCH_SELECTOR (commandPickerSelector), 0);
 				timeToGoBack = TRUE;
 				if (self->priv->instanceImportOK) reReadSettings=TRUE;
 				break;
