@@ -38,6 +38,8 @@
 #include "queen-beecon-dbus-monitor.h"
 #include "queen-beecon-dbus-service.h"
 #include "queen-beecon-settings-manager.h"
+#include "queen-beecon-orientation.h"
+#include "queen-beecon-location.h"
 
 extern gchar *qbwExecReason[];
 
@@ -102,25 +104,58 @@ gboolean queen_beecon_dbus_cb_dbus_method_monitor (QueenBeecon *self, const gcha
 	return TRUE;
 }
 
+gboolean queen_beecon_dbus_cb_reset_rearm_connection (QueenBeecon *self, GError **error)
+{
+	qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V2, "(%p) %s", self, G_STRFUNC);
+	if (self->priv->dMM) hildon_banner_show_informationf (NULL, NULL, "reset_rearm_connection@qbw(%s)", self->priv->qbwDbusId);
+
+	QbwOperationalSubsystems OSS = queen_beecon_op_subsystems_manager(self, QBW_SUBSYSTEM_RESTART, QBW_SUBSYSTEM_CONNECTION);
+	if (OSS) {gchar *x=queen_beecon_op_subsystems_error_message(OSS); hildon_banner_show_informationf (NULL, NULL, "ERROR enabling %s.\nSubsystem(s) disabled in QBW instance [%s]!", x, self->priv->qbwDbusId);g_free(x);}
+
+	return TRUE;
+}
+
+gboolean queen_beecon_dbus_cb_reset_rearm_orientation (QueenBeecon *self, GError **error)
+{
+	qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V2, "(%p) %s", self, G_STRFUNC);
+	if (self->priv->dMM) hildon_banner_show_informationf (NULL, NULL, "reset_rearm_orientation@qbw(%s)", self->priv->qbwDbusId);
+
+	QbwOperationalSubsystems OSS = queen_beecon_op_subsystems_manager(self, QBW_SUBSYSTEM_RESTART, QBW_SUBSYSTEM_ORIENTATION);
+	if (OSS) {gchar *x=queen_beecon_op_subsystems_error_message(OSS); hildon_banner_show_informationf (NULL, NULL, "ERROR enabling %s.\nSubsystem(s) disabled in QBW instance [%s]!", x, self->priv->qbwDbusId);g_free(x);}
+
+	return TRUE;
+}
+
 gboolean queen_beecon_dbus_cb_reset_rearm_timer (QueenBeecon *self, GError **error)
 {
 	qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V2, "(%p) %s", self, G_STRFUNC);
 	if (self->priv->dMM) hildon_banner_show_informationf (NULL, NULL, "reset_rearm_timer@qbw(%s)", self->priv->qbwDbusId);
 
-	if (self->priv->updateTimerID) { // New instance loaded, we assume timers need reset
-		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) removing self->priv->updateTimerID=%d", self, self->priv->updateTimerID);
-		g_source_remove (self->priv->updateTimerID);
-	}
-	if (self->priv->delayIndex) {
-		self->priv->delaySeconds = GetSeconds(self->priv->delayIndex);
-		if (self->priv->delayIndex==9) self->priv->delaySeconds = self->priv->customIntervalSecs;
-	} else {
-		self->priv->delaySeconds = 0;
-	}
-	if (self->priv->delaySeconds > 0 && self->priv->operationalStatus==0) { // New instance loaded, we assume timers need rearm if instance is enabled
-		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) re-arming execution timer, delaySeconds=%d", self, self->priv->delaySeconds);
-		self->priv->updateTimerID = g_timeout_add_seconds (self->priv->delaySeconds, (GSourceFunc)queen_beecon_update_content, self);
-	}
+	QbwOperationalSubsystems OSS = queen_beecon_op_subsystems_manager(self, QBW_SUBSYSTEM_RESTART, QBW_SUBSYSTEM_TIMER);
+	if (OSS) {gchar *x=queen_beecon_op_subsystems_error_message(OSS); hildon_banner_show_informationf (NULL, NULL, "ERROR enabling %s.\nSubsystem(s) disabled in QBW instance [%s]!", x, self->priv->qbwDbusId);g_free(x);}
+
+	return TRUE;
+}
+
+gboolean queen_beecon_dbus_cb_reset_rearm_location (QueenBeecon *self, GError **error)
+{
+	qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V2, "(%p) %s", self, G_STRFUNC);
+	if (self->priv->dMM) hildon_banner_show_informationf (NULL, NULL, "reset_rearm_location@qbw(%s)", self->priv->qbwDbusId);
+
+	QbwOperationalSubsystems OSS = queen_beecon_op_subsystems_manager(self, QBW_SUBSYSTEM_RESTART, QBW_SUBSYSTEM_LOCATION);
+	if (OSS) {gchar *x=queen_beecon_op_subsystems_error_message(OSS); hildon_banner_show_informationf (NULL, NULL, "ERROR enabling %s.\nSubsystem(s) disabled in QBW instance [%s]!", x, self->priv->qbwDbusId);g_free(x);}
+
+	return TRUE;
+}
+
+gboolean queen_beecon_dbus_cb_reset_rearm_dbus_monitor (QueenBeecon *self, GError **error)
+{
+	qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V2, "(%p) %s", self, G_STRFUNC);
+	if (self->priv->dMM) hildon_banner_show_informationf (NULL, NULL, "reset_rearm_dbus_monitor@qbw(%s)", self->priv->qbwDbusId);
+
+	QbwOperationalSubsystems OSS = queen_beecon_op_subsystems_manager(self, QBW_SUBSYSTEM_RESTART, QBW_SUBSYSTEM_DBUS_MONITOR);
+	if (OSS) {gchar *x=queen_beecon_op_subsystems_error_message(OSS); hildon_banner_show_informationf (NULL, NULL, "ERROR enabling %s.\nSubsystem(s) disabled in QBW instance [%s]!", x, self->priv->qbwDbusId);g_free(x);}
+
 	return TRUE;
 }
 
@@ -157,17 +192,11 @@ gboolean queen_beecon_dbus_cb_dbus_wakeup (QueenBeecon *self, GError **error)
 	//g_mutex_lock(QUEEN_BEECON_GET_CLASS(self)->config_file_mutex);
 	queen_beecon_write_settings (self, TRUE);
 	//g_mutex_unlock(QUEEN_BEECON_GET_CLASS(self)->config_file_mutex);
-	if( (self->priv->updateTimerID == 0) && (self->priv->delaySeconds > 0)) {
-		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) re-arming execution timer, delaySeconds=%d", self, self->priv->delaySeconds);
-		self->priv->updateTimerID = g_timeout_add_seconds (self->priv->delaySeconds, (GSourceFunc)queen_beecon_update_content, self);
-	}
-	if (self->priv->updOnDBUS && self->priv->dbus_mon_connection==NULL && self->priv->operationalStatus==0) { //Is DBUS Monitor active?
-		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) DBUS monitor starting, rearm connection, match and filter", self);
-		if (!queen_beecon_dbus_monitor_manager(self, QBW_INIT_DBUS_MONITOR, self->priv->updOnDBUSBus, self->priv->updOnDBUSMatchRule)) { // If error during reinitialization of DBUS monitor ... restore previous settings
-			self->priv->updOnDBUS          = 0;
-		}
-	}
-	if (!self->priv->updOnDBUS && self->priv->updOnStartup) queen_beecon_update_content (self, qbwExecReason[QBW_DBUS_WAKEUP]);
+
+	QbwOperationalSubsystems OSS = queen_beecon_op_subsystems_manager(self, QBW_SUBSYSTEM_INIT, QBW_SUBSYSTEM_ALL);
+	if (OSS) {gchar *x=queen_beecon_op_subsystems_error_message(OSS); hildon_banner_show_informationf (NULL, NULL, "ERROR enabling %s.\nSubsystem(s) disabled in QBW instance [%s]!", x, self->priv->qbwDbusId);g_free(x);}
+
+	if (self->priv->updOnStartup) queen_beecon_update_content (self, qbwExecReason[QBW_DBUS_WAKEUP]);
 	else queen_beecon_update_content_layout (self);
 	return TRUE;
 }
@@ -181,12 +210,7 @@ gboolean queen_beecon_dbus_cb_dbus_sleep (QueenBeecon *self, GError **error)
 	//g_mutex_lock(QUEEN_BEECON_GET_CLASS(self)->config_file_mutex);
 	queen_beecon_write_settings (self, TRUE);
 	//g_mutex_unlock(QUEEN_BEECON_GET_CLASS(self)->config_file_mutex);
-	if (self->priv->updateTimerID) {
-		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) removing self->priv->updateTimerID=%d", self, self->priv->updateTimerID);
-		g_source_remove (self->priv->updateTimerID);
-	}
-
-	queen_beecon_dbus_monitor_manager(self, QBW_DEINIT_DBUS_MONITOR, self->priv->updOnDBUSBus, self->priv->updOnDBUSMatchRule); // Disable DBUS Monitor
+	queen_beecon_op_subsystems_manager(self, QBW_SUBSYSTEM_DEINIT, QBW_SUBSYSTEM_ALL);
 
 	queen_beecon_update_content_layout (self);
 	return TRUE;
@@ -369,7 +393,7 @@ gboolean queen_beecon_dbus_cb_dbus_set_position (QueenBeecon *self, const gint w
 {
 	qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V2, "(%p) %s", self, G_STRFUNC);
 	if (self->priv->dMM) hildon_banner_show_informationf (NULL, NULL, "set_position@qbw(%s) X=%d Y=%d", self->priv->qbwDbusId, widXOrigin, widYOrigin);
-
+	self->priv->widXOrigin = widXOrigin; self->priv->widYOrigin = widYOrigin;
 	gtk_window_move (GTK_WINDOW (self), widXOrigin, widYOrigin); // Remember our position ... maybe we need to move a little bit
 	return TRUE;
 }
