@@ -36,6 +36,7 @@
 #include "queen-beecon-dbus-monitor.h"
 #include "queen-beecon-dbus-service.h"
 #include "queen-beecon-settings-manager.h"
+#include "queen-beecon-orientation.h"
 
 extern gchar *qbwExecReason[];
 
@@ -81,8 +82,8 @@ void queen_beecon_async_sync_exec_out(QueenBeecon *self, const gchar *whoareyou)
         PangoAttrList *attrs;
         gchar *text;
         if (!pango_parse_markup (self->priv->execAuxOutput, -1, 0, &attrs, &text, NULL, NULL) ) {
-    		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) QBW(%s) Warning! Possible Pango Markup Language inconsistent/unterminated Tag!", self, self->priv->qbwDbusId);
-			hildon_banner_show_informationf (NULL, NULL, "(%p) QBW Warning! Possible Pango Markup Language inconsistent/unterminated Tag!", self);
+    		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) QBW(%s-%s) Warning! Possible Pango Markup Language inconsistent/unterminated Tag!", self, self->priv->qbwDbusId, self->priv->instanceTitle);
+			hildon_banner_show_informationf (NULL, NULL, "(%p) QBW(%s-%s) Warning! Possible Pango Markup Language inconsistent/unterminated Tag!", self, self->priv->qbwDbusId, self->priv->instanceTitle);
     	}
     	g_free(self->priv->execAuxOutput);self->priv->execAuxOutput = NULL;
 
@@ -245,37 +246,70 @@ gchar *g_strreplace (const gchar *string, const gchar *search, const gchar *repl
 gchar *queen_beecon_g_command_param_subst(QueenBeecon *self, const gchar *cmd, const gchar *action)
 {
 	qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V2, "(%p) %s", self, G_STRFUNC);
+
 	gchar *r = NULL;
 	gchar *x = g_strdup(cmd);
 	gchar *b = NULL;
 	r = g_strreplace(x,"$QBW_ID",                    self->priv->qbwDbusId); g_free(x); x = r;
+
 	r = g_strreplace(x,"$QBW_ON_SIGHT",              self->priv->qbwOnSight?"true":"false"); g_free(x); x = r;
+
 	r = g_strreplace(x,"$QBW_IS_CONNECTED",          self->priv->isConnected?"true":"false"); g_free(x); x = r;
+
 	//r = g_strreplace(x,"$QBW_IS_FINGER_TAP",         self->priv->isFingerTap?"true":"false"); g_free(x); x = r;
 	r = g_strreplace(x,"$QBW_EXEC_REASON",           action); g_free(x); x = r;
+
 	b = g_strdup_printf("%d", self->priv->hotSpotIndex);
 	r = g_strreplace(x,"$QBW_HOTSPOT_PRESS",         b); g_free(b); b = NULL; g_free(x); x = r;
+
 	b = g_strdup_printf("%d", self->priv->clickX);
 	r = g_strreplace(x,"$QBW_CLICK_X",               b); g_free(b); b = NULL; g_free(x); x = r;
 	b = g_strdup_printf("%d", self->priv->clickY);
 	r = g_strreplace(x,"$QBW_CLICK_Y",               b); g_free(b); b = NULL; g_free(x); x = r;
+
+	gint widXOrigin, widYOrigin;
+	gtk_window_get_position (GTK_WINDOW (self), &widXOrigin, &widYOrigin); // Widget position
+	b = g_strdup_printf("%d", widXOrigin);
+	r = g_strreplace(x,"$QBW_POSITION_X",            b); g_free(b); b = NULL; g_free(x); x = r;
+	b = g_strdup_printf("%d", widYOrigin);
+	r = g_strreplace(x,"$QBW_POSITION_Y",            b); g_free(b); b = NULL; g_free(x); x = r;
+
 	b = g_strdup_printf("%d", (gint)self->priv->widWidth);
 	r = g_strreplace(x,"$QBW_WIDTH",                 b); g_free(b); b = NULL; g_free(x); x = r;
 	b = g_strdup_printf("%d", (gint)self->priv->widHeight);
 	r = g_strreplace(x,"$QBW_HEIGHT",                b); g_free(b); b = NULL; g_free(x); x = r;
+
+	r = g_strreplace(x,"$QBW_ORIENTATION_MODE",      QUEEN_BEECON_GET_CLASS(self)->orientationMode  ? QUEEN_BEECON_GET_CLASS(self)->orientationMode  :""); g_free(x); x = r;
+	r = g_strreplace(x,"$QBW_ORIENTATION_STAND",     QUEEN_BEECON_GET_CLASS(self)->orientationStand ? QUEEN_BEECON_GET_CLASS(self)->orientationStand :""); g_free(x); x = r;
+	r = g_strreplace(x,"$QBW_ORIENTATION_FACE",      QUEEN_BEECON_GET_CLASS(self)->orientationFace  ? QUEEN_BEECON_GET_CLASS(self)->orientationFace  :""); g_free(x); x = r;
+
+	if (g_strrstr(x,"$QBW_ORIENTATION_")) queen_beecon_orientation_manager(self, QBW_READ_ORIENTATION_XYZ);
+	b = g_strdup_printf("%d", QUEEN_BEECON_GET_CLASS(self)->orientationX);
+	r = g_strreplace(x,"$QBW_ORIENTATION_X",         b); g_free(b); b = NULL; g_free(x); x = r;
+	b = g_strdup_printf("%d", QUEEN_BEECON_GET_CLASS(self)->orientationY);
+	r = g_strreplace(x,"$QBW_ORIENTATION_Y",         b); g_free(b); b = NULL; g_free(x); x = r;
+	b = g_strdup_printf("%d", QUEEN_BEECON_GET_CLASS(self)->orientationZ);
+	r = g_strreplace(x,"$QBW_ORIENTATION_Z",         b); g_free(b); b = NULL; g_free(x); x = r;
+
 	b = g_strdup_printf("%d", self->priv->clicksCount);
 	r = g_strreplace(x,"$QBW_CLICKS_COUNT",          b); g_free(b); b = NULL; g_free(x); x = r;
+
 	r = g_strreplace(x,"$QBW_CURRENT_RESULTS_TEXT",  gtk_label_get_label(GTK_LABEL (self->priv->cmdResult_lb))); g_free(x); x = r;
 	b = g_strdup_printf("%d", self->priv->cmdExitStatus);
 	r = g_strreplace(x,"$QBW_PREVIOUS_EXIT_STATUS",  b); g_free(b); b = NULL; g_free(x); x = r;
-    r = g_strreplace(x,"$QBW_HTTP_PROXY",            self->priv->qbwHttpProxy       ? self->priv->qbwHttpProxy       :""); g_free(x); x = r;
+
+	r = g_strreplace(x,"$QBW_HTTP_PROXY",            self->priv->qbwHttpProxy       ? self->priv->qbwHttpProxy       :""); g_free(x); x = r;
 	r = g_strreplace(x,"$QBW_HTTPS_PROXY",           self->priv->qbwHttpsProxy      ? self->priv->qbwHttpsProxy      :""); g_free(x); x = r;
 	r = g_strreplace(x,"$QBW_IGNORE_HOSTS_PROXY",    self->priv->qbwIgnoreHosts     ? self->priv->qbwIgnoreHosts     :""); g_free(x); x = r;
 	r = g_strreplace(x,"$QBW_FTP_PROXY",             self->priv->qbwFtpProxy        ? self->priv->qbwFtpProxy        :""); g_free(x); x = r;
 	r = g_strreplace(x,"$QBW_SOCKS_PROXY",           self->priv->qbwSocksProxy      ? self->priv->qbwSocksProxy      :""); g_free(x); x = r;
 	r = g_strreplace(x,"$QBW_RTSP_PROXY",            self->priv->qbwRTSPProxy       ? self->priv->qbwRTSPProxy       :""); g_free(x); x = r;
 	r = g_strreplace(x,"$QBW_AUTO_CONFIG_PROXY_URL", self->priv->qbwAutoConfigProxy ? self->priv->qbwAutoConfigProxy :""); g_free(x); x = r;
-    r = g_strreplace(x,"$QBW_REMEMBER_ME",           self->priv->rememberMe         ? self->priv->rememberMe         :""); g_free(x); x = r;
+
+	r = g_strreplace(x,"$QBW_LOCATION_FIX",          self->priv->GPSfixinfo         ? self->priv->GPSfixinfo         :""); g_free(x); x = r;
+
+	r = g_strreplace(x,"$QBW_REMEMBER_ME",           self->priv->rememberMe         ? self->priv->rememberMe         :""); g_free(x); x = r;
+
 	r = g_strreplace(x,"$QBW_DBUS_VERBOSE_OUTPUT",   self->priv->dbusVerboseMsg     ? self->priv->dbusVerboseMsg->str:""); g_free(x); x = r;
 	return (r);
 }
